@@ -1,27 +1,25 @@
-// Copyright 2013-2017, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
 use glib::translate::*;
-use gtk_sys;
 use std::fmt;
 use std::ops;
 
-glib_wrapper! {
+glib::wrapper! {
     #[derive(PartialEq, Eq, PartialOrd, Ord, Hash)]
-    pub struct Border(Boxed<gtk_sys::GtkBorder>);
+    #[doc(alias = "GtkBorder")]
+    pub struct Border(Boxed<ffi::GtkBorder>);
 
     match fn {
-        copy => |ptr| gtk_sys::gtk_border_copy(mut_override(ptr)),
-        free => |ptr| gtk_sys::gtk_border_free(ptr),
+        copy => |ptr| ffi::gtk_border_copy(mut_override(ptr)),
+        free => |ptr| ffi::gtk_border_free(ptr),
         init => |_ptr| (),
         clear => |_ptr| (),
-        get_type => || gtk_sys::gtk_border_get_type(),
+        type_ => || ffi::gtk_border_get_type(),
     }
 }
 
 impl ops::Deref for Border {
-    type Target = gtk_sys::GtkBorder;
+    type Target = ffi::GtkBorder;
 
     fn deref(&self) -> &Self::Target {
         &(*self.0)
@@ -35,9 +33,10 @@ impl ops::DerefMut for Border {
 }
 
 impl Border {
-    pub fn new() -> Border {
+    #[doc(alias = "gtk_border_new")]
+    pub fn new() -> Self {
         assert_initialized_main_thread!();
-        unsafe { from_glib_full(gtk_sys::gtk_border_new()) }
+        unsafe { from_glib_full(ffi::gtk_border_new()) }
     }
 }
 
