@@ -1,17 +1,16 @@
-// Copyright 2013-2016, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
+use crate::Notebook;
+use crate::Widget;
 use glib::translate::*;
-use gtk_sys;
+use glib::IsA;
 use libc::c_int;
-use IsA;
-use Notebook;
-use Widget;
 
 pub trait NotebookExtManual: 'static {
+    #[doc(alias = "gtk_notebook_append_page")]
     fn append_page<T: IsA<Widget>, U: IsA<Widget>>(&self, child: &T, tab_label: Option<&U>) -> u32;
 
+    #[doc(alias = "gtk_notebook_append_page_menu")]
     fn append_page_menu<T, U, V>(
         &self,
         child: &T,
@@ -23,17 +22,25 @@ pub trait NotebookExtManual: 'static {
         U: IsA<Widget>,
         V: IsA<Widget>;
 
-    fn get_current_page(&self) -> Option<u32>;
+    #[doc(alias = "gtk_notebook_get_current_page")]
+    #[doc(alias = "get_current_page")]
+    fn current_page(&self) -> Option<u32>;
 
-    fn get_n_pages(&self) -> u32;
+    #[doc(alias = "gtk_notebook_get_n_pages")]
+    #[doc(alias = "get_n_pages")]
+    fn n_pages(&self) -> u32;
 
-    fn get_nth_page(&self, page_num: Option<u32>) -> Option<Widget>;
+    #[doc(alias = "gtk_notebook_get_nth_page")]
+    #[doc(alias = "get_nth_page")]
+    fn nth_page(&self, page_num: Option<u32>) -> Option<Widget>;
 
+    #[doc(alias = "gtk_notebook_insert_page")]
     fn insert_page<T, U>(&self, child: &T, tab_label: Option<&U>, position: Option<u32>) -> u32
     where
         T: IsA<Widget>,
         U: IsA<Widget>;
 
+    #[doc(alias = "gtk_notebook_insert_page_menu")]
     fn insert_page_menu<T, U, V>(
         &self,
         child: &T,
@@ -46,13 +53,16 @@ pub trait NotebookExtManual: 'static {
         U: IsA<Widget>,
         V: IsA<Widget>;
 
+    #[doc(alias = "gtk_notebook_page_num")]
     fn page_num<T: IsA<Widget>>(&self, child: &T) -> Option<u32>;
 
+    #[doc(alias = "gtk_notebook_prepend_page")]
     fn prepend_page<T, U>(&self, child: &T, tab_label: Option<&U>) -> u32
     where
         T: IsA<Widget>,
         U: IsA<Widget>;
 
+    #[doc(alias = "gtk_notebook_prepend_page_menu")]
     fn prepend_page_menu<T, U, V>(
         &self,
         child: &T,
@@ -64,17 +74,20 @@ pub trait NotebookExtManual: 'static {
         U: IsA<Widget>,
         V: IsA<Widget>;
 
+    #[doc(alias = "gtk_notebook_remove_page")]
     fn remove_page(&self, page_num: Option<u32>);
 
+    #[doc(alias = "gtk_notebook_reorder_child")]
     fn reorder_child<T: IsA<Widget>>(&self, child: &T, position: Option<u32>);
 
+    #[doc(alias = "gtk_notebook_set_current_page")]
     fn set_current_page(&self, page_num: Option<u32>);
 }
 
 impl<O: IsA<Notebook>> NotebookExtManual for O {
     fn append_page<T: IsA<Widget>, U: IsA<Widget>>(&self, child: &T, tab_label: Option<&U>) -> u32 {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_append_page(
+            let ret = ffi::gtk_notebook_append_page(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
                 tab_label.map(|p| p.as_ref()).to_glib_none().0,
@@ -96,7 +109,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
         V: IsA<Widget>,
     {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_append_page_menu(
+            let ret = ffi::gtk_notebook_append_page_menu(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
                 tab_label.map(|p| p.as_ref()).to_glib_none().0,
@@ -107,9 +120,9 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
         }
     }
 
-    fn get_current_page(&self) -> Option<u32> {
+    fn current_page(&self) -> Option<u32> {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_get_current_page(self.as_ref().to_glib_none().0);
+            let ret = ffi::gtk_notebook_get_current_page(self.as_ref().to_glib_none().0);
             if ret >= 0 {
                 Some(ret as u32)
             } else {
@@ -118,17 +131,17 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
         }
     }
 
-    fn get_n_pages(&self) -> u32 {
+    fn n_pages(&self) -> u32 {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_get_n_pages(self.as_ref().to_glib_none().0);
+            let ret = ffi::gtk_notebook_get_n_pages(self.as_ref().to_glib_none().0);
             assert!(ret >= 0);
             ret as u32
         }
     }
 
-    fn get_nth_page(&self, page_num: Option<u32>) -> Option<Widget> {
+    fn nth_page(&self, page_num: Option<u32>) -> Option<Widget> {
         unsafe {
-            from_glib_none(gtk_sys::gtk_notebook_get_nth_page(
+            from_glib_none(ffi::gtk_notebook_get_nth_page(
                 self.as_ref().to_glib_none().0,
                 page_num.map_or(-1, |n| n as c_int),
             ))
@@ -141,7 +154,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
         U: IsA<Widget>,
     {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_insert_page(
+            let ret = ffi::gtk_notebook_insert_page(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
                 tab_label.map(|p| p.as_ref()).to_glib_none().0,
@@ -165,7 +178,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
         V: IsA<Widget>,
     {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_insert_page_menu(
+            let ret = ffi::gtk_notebook_insert_page_menu(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
                 tab_label.map(|p| p.as_ref()).to_glib_none().0,
@@ -179,7 +192,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
 
     fn page_num<T: IsA<Widget>>(&self, child: &T) -> Option<u32> {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_page_num(
+            let ret = ffi::gtk_notebook_page_num(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
             );
@@ -197,7 +210,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
         U: IsA<Widget>,
     {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_prepend_page(
+            let ret = ffi::gtk_notebook_prepend_page(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
                 tab_label.map(|p| p.as_ref()).to_glib_none().0,
@@ -219,7 +232,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
         V: IsA<Widget>,
     {
         unsafe {
-            let ret = gtk_sys::gtk_notebook_prepend_page_menu(
+            let ret = ffi::gtk_notebook_prepend_page_menu(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
                 tab_label.map(|p| p.as_ref()).to_glib_none().0,
@@ -232,7 +245,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
 
     fn remove_page(&self, page_num: Option<u32>) {
         unsafe {
-            gtk_sys::gtk_notebook_remove_page(
+            ffi::gtk_notebook_remove_page(
                 self.as_ref().to_glib_none().0,
                 page_num.map_or(-1, |n| n as c_int),
             );
@@ -241,7 +254,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
 
     fn reorder_child<T: IsA<Widget>>(&self, child: &T, position: Option<u32>) {
         unsafe {
-            gtk_sys::gtk_notebook_reorder_child(
+            ffi::gtk_notebook_reorder_child(
                 self.as_ref().to_glib_none().0,
                 child.as_ref().to_glib_none().0,
                 position.map_or(-1, |n| n as c_int),
@@ -251,7 +264,7 @@ impl<O: IsA<Notebook>> NotebookExtManual for O {
 
     fn set_current_page(&self, page_num: Option<u32>) {
         unsafe {
-            gtk_sys::gtk_notebook_set_current_page(
+            ffi::gtk_notebook_set_current_page(
                 self.as_ref().to_glib_none().0,
                 page_num.map_or(-1, |n| n as c_int),
             );
