@@ -1,18 +1,16 @@
-// Copyright 2013-2018, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
 use glib::translate::*;
-use gtk_sys;
 
-use PageRange;
-use PrintSettings;
+use crate::PageRange;
+use crate::PrintSettings;
 
 impl PrintSettings {
+    #[doc(alias = "gtk_print_settings_set_page_ranges")]
     pub fn set_page_ranges(&self, page_ranges: &[PageRange]) {
         let num_ranges = page_ranges.len() as i32;
         unsafe {
-            gtk_sys::gtk_print_settings_set_page_ranges(
+            ffi::gtk_print_settings_set_page_ranges(
                 self.to_glib_none().0,
                 mut_override(page_ranges.as_ptr() as *const _),
                 num_ranges,
