@@ -1,27 +1,25 @@
-// Copyright 2013-2015, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
-use gdk;
-use glib;
 use glib::translate::*;
-use gtk_sys;
-use libc::c_uint;
 use std::cell::Cell;
-use std::ptr;
-use std::sync::atomic::{AtomicBool, Ordering, ATOMIC_BOOL_INIT};
+use std::sync::atomic::{AtomicBool, Ordering};
+
+#[cfg(target_os = "macos")]
+extern "C" {
+    fn pthread_main_np() -> i32;
+}
 
 thread_local! {
     static IS_MAIN_THREAD: Cell<bool> = Cell::new(false)
 }
 
-static INITIALIZED: AtomicBool = ATOMIC_BOOL_INIT;
+static INITIALIZED: AtomicBool = AtomicBool::new(false);
 
 /// Asserts that this is the main thread and `gtk::init` has been called.
 macro_rules! assert_initialized_main_thread {
     () => {
-        if !::rt::is_initialized_main_thread() {
-            if ::rt::is_initialized() {
+        if !crate::rt::is_initialized_main_thread() {
+            if crate::rt::is_initialized() {
                 panic!("GTK may only be used from the main thread.");
             } else {
                 panic!("GTK has not been initialized. Call `gtk::init` first.");
@@ -39,7 +37,7 @@ macro_rules! skip_assert_initialized {
 #[allow(unused_macros)]
 macro_rules! assert_not_initialized {
     () => {
-        if ::rt::is_initialized() {
+        if crate::rt::is_initialized() {
             panic!("This function has to be called before `gtk::init`.");
         }
     };
@@ -60,6 +58,19 @@ pub fn is_initialized_main_thread() -> bool {
 }
 
 /// Informs this crate that GTK has been initialized and the current thread is the main one.
+///
+/// # Panics
+///
+/// This function will panic if you attempt to initialise GTK from more than
+/// one thread.
+///
+/// # Safety
+///
+/// You must only call this if:
+///
+/// 1. You have initialised the underlying GTK library yourself.
+/// 2. You did 1 on the thread with which you are calling this function
+/// 3. You ensure that this thread is the main thread for the process.
 pub unsafe fn set_initialized() {
     skip_assert_initialized!();
     if is_initialized_main_thread() {
@@ -67,6 +78,15 @@ pub unsafe fn set_initialized() {
     } else if is_initialized() {
         panic!("Attempted to initialize GTK from two different threads.");
     }
+
+    //  OS X has its own notion of the main thread and init must be called on that thread.
+    #[cfg(target_os = "macos")]
+    {
+        if pthread_main_np() == 0 {
+            panic!("Attempted to initialize GTK on OSX from non-main thread");
+        }
+    }
+
     gdk::set_initialized();
     INITIALIZED.store(true, Ordering::Release);
     IS_MAIN_THREAD.with(|c| c.set(true));
@@ -83,6 +103,7 @@ pub unsafe fn set_initialized() {
 /// so will not cause the program to terminate if GTK could not be initialized.
 /// Instead, an Ok is returned if the windowing system was successfully
 /// initialized otherwise an Err is returned.
+#[doc(alias = "gtk_init")]
 pub fn init() -> Result<(), glib::BoolError> {
     skip_assert_initialized!();
     if is_initialized_main_thread() {
@@ -91,66 +112,51 @@ pub fn init() -> Result<(), glib::BoolError> {
         panic!("Attempted to initialize GTK from two different threads.");
     }
     unsafe {
-        if from_glib(gtk_sys::gtk_init_check(ptr::null_mut(), ptr::null_mut())) {
-            if !glib::MainContext::default().acquire() {
-                return Err(glib_bool_error!("Failed to acquire default main context"));
-            }
+        // We just want to keep the program's name since more arguments could lead to unwanted
+        // behaviors...
+        let argv = ::std::env::args().take(1).collect::<Vec<_>>();
 
+        if from_glib(ffi::gtk_init_check(&mut 1, &mut argv.to_glib_none().0)) {
+            // See https://github.com/gtk-rs/gtk-rs-core/issues/186 for reasoning behind
+            // acquiring and leaking the main context here.
+            let result: bool = from_glib(glib::ffi::g_main_context_acquire(
+                glib::ffi::g_main_context_default(),
+            ));
+            if !result {
+                return Err(glib::bool_error!("Failed to acquire default main context"));
+            }
             set_initialized();
             Ok(())
         } else {
-            Err(glib_bool_error!("Failed to initialize GTK"))
+            Err(glib::bool_error!("Failed to initialize GTK"))
         }
     }
 }
 
+#[doc(alias = "gtk_main_quit")]
 pub fn main_quit() {
     assert_initialized_main_thread!();
     unsafe {
-        if gtk_sys::gtk_main_level() > 0 {
-            gtk_sys::gtk_main_quit();
+        if ffi::gtk_main_level() > 0 {
+            ffi::gtk_main_quit();
         } else if cfg!(debug_assertions) {
             panic!("Attempted to quit a GTK main loop when none is running.");
         }
     }
 }
 
-pub fn get_major_version() -> u32 {
-    skip_assert_initialized!();
-    unsafe { gtk_sys::gtk_get_major_version() as u32 }
-}
+#[cfg(test)]
+mod tests {
+    use crate::TEST_THREAD_WORKER;
 
-pub fn get_minor_version() -> u32 {
-    skip_assert_initialized!();
-    unsafe { gtk_sys::gtk_get_minor_version() as u32 }
-}
-
-pub fn get_micro_version() -> u32 {
-    skip_assert_initialized!();
-    unsafe { gtk_sys::gtk_get_micro_version() as u32 }
-}
-
-pub fn get_binary_age() -> u32 {
-    skip_assert_initialized!();
-    unsafe { gtk_sys::gtk_get_binary_age() as u32 }
-}
-
-pub fn get_interface_age() -> u32 {
-    skip_assert_initialized!();
-    unsafe { gtk_sys::gtk_get_interface_age() as u32 }
-}
-
-pub fn check_version(
-    required_major: u32,
-    required_minor: u32,
-    required_micro: u32,
-) -> Option<String> {
-    skip_assert_initialized!();
-    unsafe {
-        from_glib_none(gtk_sys::gtk_check_version(
-            required_major as c_uint,
-            required_minor as c_uint,
-            required_micro as c_uint,
-        ))
+    #[test]
+    fn init_should_acquire_default_main_context() {
+        TEST_THREAD_WORKER
+            .push(move || {
+                let context = glib::MainContext::ref_thread_default();
+                assert!(context.is_owner());
+            })
+            .expect("Failed to schedule a test call");
+        while TEST_THREAD_WORKER.unprocessed() > 0 {}
     }
 }
