@@ -1,63 +1,10 @@
-// Copyright 2015, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
 use gdk::Rectangle;
-use glib;
 pub use glib::signal::Inhibit;
 use glib::signal::SignalHandlerId;
-use glib::SourceId;
 
-use {Continue, ScrollType, Widget};
-
-/// Adds a closure to be called by the default main loop when it's idle.
-///
-/// `func` will be called repeatedly until it returns `Continue(false)`.
-///
-/// Similar to `glib::idle_add` but only callable from the main thread and
-/// doesn't require `Send`. It is the same as `glib::idle_add_local`.
-pub fn idle_add<F>(func: F) -> SourceId
-where
-    F: FnMut() -> Continue + 'static,
-{
-    assert_initialized_main_thread!();
-    glib::idle_add_local(func)
-}
-
-/// Adds a closure to be called by the default main loop at regular intervals
-/// with millisecond granularity.
-///
-/// `func` will be called repeatedly every `interval` milliseconds until it
-/// returns `Continue(false)`. Precise timing is not guaranteed, the timeout may
-/// be delayed by other events. Prefer `timeout_add_seconds` when millisecond
-/// precision is not necessary.
-///
-/// Similar to `glib::timeout_add` but only callable from the main thread and
-/// doesn't require `Send`. It is the same as `glib::timeout_add_local`.
-pub fn timeout_add<F>(interval: u32, func: F) -> SourceId
-where
-    F: FnMut() -> Continue + 'static,
-{
-    assert_initialized_main_thread!();
-    glib::timeout_add_local(interval, func)
-}
-
-/// Adds a closure to be called by the default main loop at regular intervals
-/// with second granularity.
-///
-/// `func` will be called repeatedly every `interval` seconds until it
-/// returns `Continue(false)`. Precise timing is not guaranteed, the timeout may
-/// be delayed by other events.
-///
-/// Similar to `glib::timeout_add_seconds` but only callable from the main thread and
-/// doesn't require `Send`. It is the same as `glib::timeout_add_seconds_local`.
-pub fn timeout_add_seconds<F>(interval: u32, func: F) -> SourceId
-where
-    F: FnMut() -> Continue + 'static,
-{
-    assert_initialized_main_thread!();
-    glib::timeout_add_seconds_local(interval, func)
-}
+use crate::{ScrollType, Widget};
 
 pub trait EditableSignals: 'static {
     fn connect_changed<F>(&self, changed_func: F) -> SignalHandlerId
@@ -72,17 +19,17 @@ pub trait EditableSignals: 'static {
 }
 
 mod editable {
+    use crate::Editable;
+    use ffi::GtkEditable;
     use glib::object::Cast;
     use glib::signal::{connect_raw, SignalHandlerId};
     use glib::translate::*;
-    use gtk_sys::GtkEditable;
+    use glib::IsA;
     use libc::{c_char, c_int, c_uchar};
     use std::ffi::CStr;
     use std::mem::transmute;
     use std::slice;
     use std::str;
-    use Editable;
-    use IsA;
 
     impl<T: IsA<Editable>> super::EditableSignals for T {
         fn connect_changed<F>(&self, changed_func: F) -> SignalHandlerId
@@ -94,7 +41,9 @@ mod editable {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"changed\0".as_ptr() as *mut _,
-                    Some(transmute(trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
@@ -109,7 +58,9 @@ mod editable {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"delete-text\0".as_ptr() as *mut _,
-                    Some(transmute(delete_trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        delete_trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
@@ -124,7 +75,9 @@ mod editable {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"insert-text\0".as_ptr() as *mut _,
-                    Some(transmute(insert_trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        insert_trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
@@ -135,7 +88,7 @@ mod editable {
     where
         T: IsA<Editable>,
     {
-        f(&Editable::from_glib_borrow(this).unsafe_cast());
+        f(Editable::from_glib_borrow(this).unsafe_cast_ref());
     }
 
     unsafe extern "C" fn delete_trampoline<T, F: Fn(&T, i32, i32) + 'static>(
@@ -147,7 +100,7 @@ mod editable {
         T: IsA<Editable>,
     {
         f(
-            &Editable::from_glib_borrow(this).unsafe_cast(),
+            Editable::from_glib_borrow(this).unsafe_cast_ref(),
             start_pos,
             end_pos,
         );
@@ -169,9 +122,10 @@ mod editable {
         };
         let string = str::from_utf8(buf).unwrap();
         f(
-            &Editable::from_glib_borrow(this).unsafe_cast(),
+            Editable::from_glib_borrow(this).unsafe_cast_ref(),
             string,
-            transmute(position),
+            // To cast a mutable pointer into a mutable reference.
+            &mut *position,
         );
     }
 }
@@ -195,21 +149,21 @@ pub trait SpinButtonSignals: 'static {
 }
 
 mod spin_button {
+    use crate::Inhibit;
+    use crate::ScrollType;
+    use crate::SpinButton;
+    use ffi::{GtkScrollType, GtkSpinButton, GTK_INPUT_ERROR};
+    use glib::ffi::gboolean;
+    use glib::ffi::{GFALSE, GTRUE};
     use glib::object::Cast;
     use glib::signal::{connect_raw, SignalHandlerId};
     use glib::translate::*;
     use glib::IsA;
-    use glib_sys::gboolean;
-    use glib_sys::{GFALSE, GTRUE};
-    use gtk_sys::{GtkSpinButton, GTK_INPUT_ERROR};
     use libc::{c_double, c_int};
     use std::boxed::Box as Box_;
     use std::mem::transmute;
-    use Inhibit;
-    use ScrollType;
-    use SpinButton;
 
-    impl<T: IsA<SpinButton>> ::SpinButtonSignals for T {
+    impl<T: IsA<SpinButton>> crate::SpinButtonSignals for T {
         fn connect_change_value<F>(&self, change_value_func: F) -> SignalHandlerId
         where
             F: Fn(&Self, ScrollType) + 'static,
@@ -219,7 +173,9 @@ mod spin_button {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"change_value\0".as_ptr() as *mut _,
-                    Some(transmute(change_trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        change_trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
@@ -234,7 +190,9 @@ mod spin_button {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"input\0".as_ptr() as *mut _,
-                    Some(transmute(input_trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        input_trampoline::<Self, F> as *const (),
+                    )),
                     Box_::into_raw(f),
                 )
             }
@@ -249,7 +207,9 @@ mod spin_button {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"output\0".as_ptr() as *mut _,
-                    Some(transmute(output_trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        output_trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
@@ -264,7 +224,9 @@ mod spin_button {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"value-changed\0".as_ptr() as *mut _,
-                    Some(transmute(trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
@@ -279,7 +241,9 @@ mod spin_button {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"wrapped\0".as_ptr() as *mut _,
-                    Some(transmute(trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
@@ -288,12 +252,15 @@ mod spin_button {
 
     unsafe extern "C" fn change_trampoline<T, F: Fn(&T, ScrollType) + 'static>(
         this: *mut GtkSpinButton,
-        scroll: ScrollType,
+        scroll: GtkScrollType,
         f: &F,
     ) where
         T: IsA<SpinButton>,
     {
-        f(&SpinButton::from_glib_borrow(this).unsafe_cast(), scroll)
+        f(
+            SpinButton::from_glib_borrow(this).unsafe_cast_ref(),
+            from_glib(scroll),
+        )
     }
 
     unsafe extern "C" fn input_trampoline<T, F: Fn(&T) -> Option<Result<f64, ()>> + 'static>(
@@ -304,7 +271,7 @@ mod spin_button {
     where
         T: IsA<SpinButton>,
     {
-        match f(&SpinButton::from_glib_borrow(this).unsafe_cast()) {
+        match f(SpinButton::from_glib_borrow(this).unsafe_cast_ref()) {
             Some(Ok(v)) => {
                 *new_value = v;
                 GTRUE
@@ -321,14 +288,14 @@ mod spin_button {
     where
         T: IsA<SpinButton>,
     {
-        f(&SpinButton::from_glib_borrow(this).unsafe_cast()).to_glib()
+        f(SpinButton::from_glib_borrow(this).unsafe_cast_ref()).into_glib()
     }
 
     unsafe extern "C" fn trampoline<T, F: Fn(&T) + 'static>(this: *mut GtkSpinButton, f: &F)
     where
         T: IsA<SpinButton>,
     {
-        f(&SpinButton::from_glib_borrow(this).unsafe_cast())
+        f(SpinButton::from_glib_borrow(this).unsafe_cast_ref())
     }
 }
 
@@ -339,20 +306,20 @@ pub trait OverlaySignals: 'static {
 }
 
 mod overlay {
+    use crate::Overlay;
+    use crate::Widget;
+    use ffi::{GtkOverlay, GtkWidget};
+    use gdk::ffi::GdkRectangle;
     use gdk::Rectangle;
-    use gdk_sys::GdkRectangle;
+    use glib::ffi::{gboolean, gpointer};
     use glib::object::Cast;
     use glib::signal::{connect_raw, SignalHandlerId};
     use glib::translate::*;
-    use glib_sys::{gboolean, gpointer};
-    use gtk_sys::{GtkOverlay, GtkWidget};
+    use glib::IsA;
     use std::mem::transmute;
     use std::ptr;
-    use IsA;
-    use Overlay;
-    use Widget;
 
-    impl<O: IsA<Overlay>> ::OverlaySignals for O {
+    impl<O: IsA<Overlay>> crate::OverlaySignals for O {
         fn connect_get_child_position<F>(&self, f: F) -> SignalHandlerId
         where
             F: Fn(&Self, &Widget) -> Option<Rectangle> + 'static,
@@ -362,14 +329,17 @@ mod overlay {
                 connect_raw(
                     self.to_glib_none().0 as *mut _,
                     b"get-child-position\0".as_ptr() as *mut _,
-                    Some(transmute(get_child_position_trampoline::<Self, F> as usize)),
+                    Some(transmute::<_, unsafe extern "C" fn()>(
+                        child_position_trampoline::<Self, F> as *const (),
+                    )),
                     Box::into_raw(f),
                 )
             }
         }
     }
 
-    unsafe extern "C" fn get_child_position_trampoline<
+    #[doc(alias = "get_child_position_trampoline")]
+    unsafe extern "C" fn child_position_trampoline<
         T,
         F: Fn(&T, &Widget) -> Option<Rectangle> + 'static,
     >(
@@ -383,7 +353,7 @@ mod overlay {
     {
         let f: &F = &*(f as *const F);
         match f(
-            &Overlay::from_glib_borrow(this).unsafe_cast(),
+            Overlay::from_glib_borrow(this).unsafe_cast_ref(),
             &from_glib_borrow(widget),
         ) {
             Some(rect) => {
@@ -392,6 +362,6 @@ mod overlay {
             }
             None => false,
         }
-        .to_glib()
+        .into_glib()
     }
 }
